@@ -7,6 +7,7 @@ USER_AGENT = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:84.0) Gecko/20100101
 
 CLIENT_ID = 's2frr164040bp9l6mgurxaz32i6rm1'
 
+
 class TwitchClient:
 
   def __init__(self, client_id: str = CLIENT_ID):
@@ -24,7 +25,7 @@ class TwitchClient:
 
     return video_json['channel']['name']
 
-  def GetVideo(self, video_id) -> dict[str, typing.Any]:
+  def GetVideo(self, video_id) -> Dict[str, typing.Any]:
     url = BASE_URL % 'videos/' + str(video_id)
     return self._GetUrl(url)
 
